@@ -1,10 +1,9 @@
 """IFD SLONG tag structure parser module."""
 
-from exif.ifd_tag._base import Base as BaseIfdTag
+from ._base import Base as BaseIfdTag
 
 
 class Slong(BaseIfdTag):
-
     """IFD SLONG tag structure parser class."""
 
     def modify(self, value):  # pragma: no cover
